%global kbd %{_exec_prefix}/lib/kbd

Summary: Utilities for managing Linux console (console, virtual terminals, keyboard, etc.)
Name:    kbd
Version: 2.6.1
Release: 5%{?dist}
License: GPLv2+
URL:     http://www.kbd-project.org/
Source0: https://mirrors.edge.kernel.org/pub/linux/utils/kbd/kbd-%{version}.tar.xz
Source1: kbd-latsun-fonts.tar.bz2
Source2: kbd-latarcyrheb-32.tar.bz2
Source3: xml2lst.pl
Source4: vlock.pamd
Source5: kbdinfo.1
Source6: cz-map.patch

# unicode_start take default font from vconsole.conf
Patch3000: kbd-1.15-unicode_start.patch
# fixes decimal separator in Swiss German keyboard layout, bz 882529
Patch3001: kbd-1.15.5-sg-decimal-separator.patch

# adds xkb and legacy keymaps subdirs to loadkyes search path
# https://bugzilla.redhat.com/show_bug.cgi?id=1028207
Patch3002: kbd-1.15.5-loadkeys-search-path.patch
# fixes issues found by static analysis
Patch3003: kbd-2.4.0-covscan-fixes.patch

BuildRequires: gcc, bison, flex, gettext, make
BuildRequires: console-setup, xkeyboard-config
BuildRequires: pam-devel, check-devel, automake

Requires: kbd-misc = %{version}-%{release}

Provides: vlock = %{version}
Conflicts: vlock <= 1.3

%description
This package contains utilities for managing Linux console 
(Linux console, virtual terminals, keyboard, etc.) – mainly, 
what they do is loading console fonts and keyboard maps. 
The utilities use kernel interfaces to load the keymap.


%package misc
Summary: Data for kbd package
BuildArch: noarch
 
%description misc
kbd-misc package contains data for kbd package - console fonts,
keymaps etc. kbd-misc should be used with kbd.


%prep
%setup -q -a 1 -a 2
cp -fp %{SOURCE3} .
cp -fp %{SOURCE6} .
%autopatch -p1

aclocal
autoconf


pushd data/keymaps/i386
cp qwerty/pt-latin9.map qwerty/pt.map
cp qwerty/sv-latin1.map qwerty/se-latin1.map

mv azerty/fr.map azerty/fr-old.map
cp azerty/fr-latin9.map azerty/fr.map
cp azerty/fr-latin9.map azerty/fr-latin0.map 


mv fgGIod/trf.map fgGIod/trf-fgGIod.map
mv olpc/es.map olpc/es-olpc.map
mv olpc/pt.map olpc/pt-olpc.map
mv qwerty/cz.map qwerty/cz-qwerty.map
popd

pushd po
rm -f gr.po gr.gmo
popd


%build
%configure --prefix=%{_prefix} --datadir=%{kbd} --mandir=%{_mandir} --localedir=%{_datadir}/locale --enable-nls
%make_build

%install
%make_install

rm -rf $RPM_BUILD_ROOT%{kbd}/keymaps/{amiga,atari,i386,include,mac,ppc,sun}

# install kbdinfo manpage
gzip -c %SOURCE5 > $RPM_BUILD_ROOT/%{_mandir}/man1/kbdinfo.1.gz

# Install PAM configuration for vlock (rhel#913309)
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
install -m 644 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/vlock



mkdir -p $RPM_BUILD_ROOT%{kbd}/keymaps/xkb
perl xml2lst.pl < /usr/share/X11/xkb/rules/base.xml > layouts-variants.lst
while read line; do
  XKBLAYOUT=`echo "$line" | cut -d " " -f 1`
  echo "$XKBLAYOUT" >> layouts-list.lst
  XKBVARIANT=`echo "$line" | cut -d " " -f 2`
  ckbcomp -rules base "$XKBLAYOUT" "$XKBVARIANT" | gzip > $RPM_BUILD_ROOT%{kbd}/keymaps/xkb/"$XKBLAYOUT"-"$XKBVARIANT".map.gz
done < layouts-variants.lst


cat layouts-list.lst | sort -u >> layouts-list-uniq.lst
while read line; do
  ckbcomp -rules base "$line" | gzip > $RPM_BUILD_ROOT%{kbd}/keymaps/xkb/"$line".map.gz
done < layouts-list-uniq.lst

# https://bugzilla.redhat.com/show_bug.cgi?id=1031848
zgrep -L "U+0041" $RPM_BUILD_ROOT%{kbd}/keymaps/xkb/* | xargs rm -f

# https://bugzilla.redhat.com/show_bug.cgi?id=1181581)
if [ -f "$RPM_BUILD_ROOT%{kbd}/keymaps/xkb/cz.map.gz" ]; then
  gunzip $RPM_BUILD_ROOT%{kbd}/keymaps/xkb/cz.map.gz
  patch $RPM_BUILD_ROOT%{kbd}/keymaps/xkb/cz.map < %{SOURCE6}
  gzip $RPM_BUILD_ROOT%{kbd}/keymaps/xkb/cz.map
fi

%find_lang %{name}

%check
make check

%files -f %{name}.lang
%license COPYING
%doc ChangeLog AUTHORS README docs/doc/kbd.FAQ*.html docs/doc/font-formats/*.html docs/doc/utf/utf* docs/doc/dvorak/*
%{_bindir}/*
%{_mandir}/*/*
%config(noreplace) %{_sysconfdir}/pam.d/vlock

%exclude %{_libdir}/libtswrap*
%exclude %{_prefix}/lib/debug/%{_libdir}/libtswrap*

%files misc
%{kbd}


%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-3
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Sep 04 2023 Wang Guodong <gordonwwang@tencent.com> - 2.6.1-2
- Update patch for cz-map

* Wed Aug 23 2023 Wang Guodong <gordonwwang@tencent.com> - 2.6.1-1
- Upgrade to version 2.6.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.0-2
- Rebuilt for OpenCloudOS Stream 23

* Mon May 30 2022 Yi Lin <nilusyi@tencent.com> - 2.4.0-1
- package init.
